Structs
- Joint
Embedding Output - Output container for single-pass joint multi-modal / BGE-M3 embedding.
- Sparse
Embedder - Local sparse-only helper (no dense model).
Traits
- Embedder
- Host-agnostic embedding backend.
- Embedder
Bound
Functions
- cross_
rerank_ unsupported_ error - Error when cross-encoder pair rerank is requested without a scorer host.
- image_
unsupported_ error - Error when image embedding is requested but the host has no image path.
- multi_
unsupported_ error - Error when multi-vector embedding is requested but the host has no multi path.
- sparse_
model_ unsupported_ error - Error when a sparse model is requested that this embedder cannot satisfy.